@@ -1,4 +1,4 @@
-from parallel_ga_processing.algorithmRunners import run_coarse_grained_ga
+from parallel_ga_processing.algorithmRunners import run_fine_grained_ga
 import math
 
 
@@ -7,7 +7,7 @@ def fitness(chromosome):
 
 
 if __name__ == '__main__':
-    run_coarse_grained_ga(population_size=(6, 6), chromosome_size=4,
+    run_fine_grained_ga(population_size=(5, 4), chromosome_size=4,
                         number_of_generations=6,
                         neighbourhood_size=1, server_ip_addr="127.0.0.1", fitness=fitness,
-                        num_of_migrants=1)
+                        mate_best_neighbouring_individual=True, server_user="genetic1", server_password="genetic1")
