@@ -2,15 +2,19 @@ import random
 from scoop import logger
 from .decorator import log_method
 from parallel_ga_processing.geneticAlgorithms import geneticGrainedBase
-
+import uuid
 
 class CoarseGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
     def __init__(self, population_size, chromosome_size,
-                 number_of_generations,
-                 neighbourhood_size, num_of_migrants, fitness):
+                          number_of_generations,
+                          neighbourhood_size, server_ip_addr, server_user,
+                          server_password, num_of_migrants,
+                          fitness):
         super().__init__(population_size, chromosome_size,
-                         number_of_generations,
-                         neighbourhood_size, fitness)
+                          number_of_generations,
+                          neighbourhood_size, server_ip_addr, server_user,
+                          server_password,
+                          fitness)
         self._num_of_migrants = num_of_migrants
         self._population = None
 
@@ -61,10 +65,10 @@ class CoarseGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
         # if none of individuals were selected
         # try it once again
         if len(chromosomes_reproducing) is 0:
-            return
+            raise ValueError("something went wrong")
         # remove old population
-        del self._population[:]
-
+        #del self._population[:]
+        tmp = []
         # Reproducing requires two individuals.
         # If number of selected individuals is even
         # put the best individual to the new population.
@@ -72,7 +76,7 @@ class CoarseGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
         # for reproduction
 
         if len(chromosomes_reproducing) % 2 == 0:
-            self._population.append(best_individual.chromosome)
+            tmp.append(best_individual.chromosome)
         else:
             # put the best individual to max index in order to not rewrite existing
             chromosomes_reproducing.append(best_individual)
@@ -84,16 +88,18 @@ class CoarseGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
             mother = chromosomes_reproducing.pop(random.randrange(len(
                 chromosomes_reproducing))).chromosome
             logger.info("father " + str(father) + " mother " + str(mother))
-            self._crossover(father, mother)
-            # mutate
-            self._mutation(father)
-            self._mutation(mother)
-            self._population.append(father)
-            self._population.append(mother)
+            # self._crossover(father, mother)
+            # # mutate
+            # self._mutation(father)
+            # self._mutation(mother)
+            tmp.append(father)
+            tmp.append(mother)
+
 
         # Generate new individuals in order to make new population the same size
-        while len(self._population) != self._population_size:
-            self._population.append(self._gen_individual())
+        while len(tmp) <= self._population_size:
+            tmp.append(self._gen_individual())
+        self._population = tmp
 
     def _evaluate_population(self):
         """
@@ -108,11 +114,8 @@ class CoarseGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
         return evaluation_data
 
     def _check_collected_data(self, neighbours):
-        if len(neighbours.objects) >= self._num_of_neighbours:
-            for x in neighbours.objects.keys():
-                logger.info("FUCK" + str(neighbours.size_of_col(int(x))))
-                if neighbours.size_of_col(int(x)) != self._num_of_migrants:
-                    return False
+        if len(neighbours.objects) >= 2:
+
             return True
         return False
 
@@ -132,7 +135,7 @@ class CoarseGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
         """
         for x in neighbouring_individuals.individuals:
             self._replace_old_individuals_with_new(x.chromosome)
-        return self._find_solution(self._population, self._num_of_migrants)
+        return self._find_solution(self._population, 1)
 
     def _replace_old_individuals_with_new(self, neighbouring_individual):
         new_chromosome = list(map(int, neighbouring_individual))
