@@ -6,12 +6,13 @@ from parallel_ga_processing.geneticAlgorithms import geneticGrainedBase
 
 class FineGrainedBase(geneticGrainedBase.GrainedGeneticAlgorithmBase):
     def __init__(self, population_size, chromosome_size,
-                 number_of_generations, server_ip_addr,
+                 number_of_generations, server_ip_addr, server_user, server_password,
                  neighbourhood_size, fitness, mate_best_neighbouring_individual=True):
 
         super().__init__(population_size, chromosome_size,
-                         number_of_generations, server_ip_addr,
-                         neighbourhood_size, fitness)
+                         number_of_generations, neighbourhood_size, server_ip_addr, server_user,
+                         server_password,
+                         fitness)
         self._chromosome = None
         self.mate_best_neighbouring_individual = mate_best_neighbouring_individual
 
