@@ -1,19 +1,22 @@
+import uuid
 import time
+import threading
 import numpy as np
 from scoop import logger
 from .decorator import log_method
 from .decorator import timeout
 from .geneticBase import GeneticAlgorithmBase
-from .messenger import ProductionQueue
-from .messenger import Messenger
-import uuid
 from enum import Enum
+from .messenger import Messenger
+from .messenger import ProductionQueue
 
 
 class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
     def __init__(self, population_size, chromosome_size,
                  number_of_generations,
-                 neighbourhood_size, fitness):
+                 neighbourhood_size, server_ip_addr, server_user,
+                 server_password,
+                 fitness):
         self._population_size_x, self._population_size_y = population_size
         super().__init__(population_size=self._population_size_x * self._population_size_y,
                          chromosome_size=chromosome_size,
@@ -26,22 +29,15 @@ class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
         self._chromosome_size = chromosome_size
         self._number_of_generations = number_of_generations
 
-        self._server_ip_addr = None
-        self._server_user = None
-        self._server_password = None
+        self._server_ip_addr = server_ip_addr
         self._data_channel = None
         self._confirmation_channel = None
         self._connection = None
-        self._producing_routing_key = None
-        self._confirmation_routing_key = None
-
+        self._server_user = server_user
+        self._server_password = server_password
         self._producing_queue = ProductionQueue()
         self._data_consuming_queue = ProductionQueue()
 
-        self._queues_to_consume = None
-        self._queue_to_produce = None
-        self._msg = None
-
     @staticmethod
     def _check_population_size(dimension_size, neighbourhood_size):
         neighbourhood_diameter = ((neighbourhood_size * 2) + 1)
@@ -63,21 +59,33 @@ class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
 
     @log_method()
     def _start_MPI(self, channels):
-        logger.info("_start_MPI"+str(self._server_ip_addr) + str(self._server_user) + str(
-            self._server_password))
-        self._queue_to_produce = int(channels.pop(0))
-        self._queues_to_consume = list(map(int, channels.pop(0)))
-        self._msg = Messenger(server_ip_addr=self._server_ip_addr, server_user=self._server_user,
-                              server_password=self._server_password,
-                              produced_messages=self._producing_queue,
-                              exchange='direct_logs', exchange_type='direct',
-                              subscription_routing_keys=self._queues_to_consume,
-                              queue=str(uuid.uuid4()),
-                              consumed_messages=self._data_consuming_queue)
+        self._queue_to_produce = str(channels.pop(0))
+        self._queues_to_consume = list(map(str, channels.pop(0)))
+        logger.info("starting processing to queue: " + self._queue_to_produce
+                    + " and consuming from: " + str(self._queues_to_consume))
 
-        self._msg.start()
+        msg = Messenger(server_user=self._server_user, server_password=self._server_password,
+                        server_ip_addr=self._server_ip_addr,
+                        exchange="data",
+                        exchange_type="direct",
+                        queue=str(uuid.uuid4()), subscription_routing_keys=self._queues_to_consume,
+                        produced_messages=self._producing_queue,
+                        consumed_messages=self._data_consuming_queue)
+        self._messenger = msg
+        self._messenger.start()
         time.sleep(2)
 
+    class Th(threading.Thread):
+        def __init__(self, messenger):
+            self._messenger = messenger
+            threading.Thread.__init__(self)
+
+        def run(self):
+            self._messenger.run()
+
+        def stop(self):
+            self._messenger.stop_consuming()
+
     @log_method()
     def _process(self):
         raise NotImplementedError
@@ -88,7 +96,7 @@ class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
 
     @log_method()
     def _stop_MPI(self):
-        self._msg.stop_consuming()
+        self._messenger.stop_consuming()
 
     @staticmethod
     def _neighbours(mat, row, col, rows, cols, radius):
@@ -134,13 +142,26 @@ class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
 
     @log_method()
     @timeout(60)
-    def _collect_data(self, current_generation):
+    def _collect_data(self, current_generation, write):
         """
         Collects individual's data from neighbouring demes
         :returns best individual from neighbouring demes
         """
         neighbours = self._Individuals()
         while True:
+            text_file = open(write, "w")
+
+            text_file.write(str(time.strftime("%Y-%m-%d %H:%M:%S", time.gmtime())) + " " + str(
+                current_generation) + " z " + str(
+                self._number_of_generations)
+                            + " pocet prijatych je " + str(len(neighbours.objects))
+                            + " neighbours " + str(neighbours.objects))
+            text_file.close()
+
+
+            if self._check_collected_data(neighbours):
+                break
+
             if not self._data_consuming_queue.is_ready(current_generation):
                 continue
             data = self._data_consuming_queue.consume_message(current_generation)
@@ -151,8 +172,7 @@ class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
 
             logger.info("RECEIVED data" + str(data.data) + str(data.source))
 
-            if self._check_collected_data(neighbours):
-                break
+
         logger.info("YEAHH " + str(self._queue_to_produce))
         return neighbours
 
@@ -171,32 +191,38 @@ class GrainedGeneticAlgorithmBase(GeneticAlgorithmBase):
     def _store_initial_data(self, initial_data):
         raise NotImplementedError
 
-    def __call__(self, initial_data, channels, server_ip_addr, server_user, server_password):
-
-        self._server_ip_addr = server_ip_addr
-        self._server_user = server_user
-        self._server_password = server_password
+    def __call__(self, initial_data, channels):
         to_return = []
         self._store_initial_data(initial_data)
-        logger.info("Process started with initial data " + str(initial_data) +
-                    " and channels " + str(channels))
-
-        self._start_MPI(channels)
 
+        #self._start_MPI(channels)
+        write = str(uuid.uuid4())
         for generation in range(0, self._number_of_generations):
             logger.info("NUM " + str(self._number_of_generations))
             logger.info("GENERATION " + str(generation))
-            data = self._process()
-            self._producing_queue.add_message(generation, Data(MessageType.DATA, generation,
-                                                               self._queue_to_produce,
-                                                               self._queue_to_produce, data))
 
-            received_data = self._collect_data(generation)
+            #text_file = open(write, "w")
+#
+            #text_file.write(str(time.strftime("%Y-%m-%d %H:%M:%S", time.gmtime())) + " " + str(
+            #    generation) + " z " + str(
+            #    self._number_of_generations)
+            #                )
+           # text_file.close()
+
+
+            data = self._process()
+            #self._producing_queue.add_message(generation, Data(MessageType.DATA, generation,
+             #                                                  self._queue_to_produce,
+             #                                                  self._queue_to_produce, data))
+            received_data= self._Individuals()
+            received_data.append_object(self._Individual(float(8), self._gen_individual()),
+                                     source='3')
+            #self._collect_data(generation, write)
             chosen_individuals_from_neighbours = self._choose_individuals_based_on_fitness(
                 received_data)
             to_return = self._finish_processing(chosen_individuals_from_neighbours)
-        self._stop_MPI()
-        return to_return
+        #self._stop_MPI()
+        return [self._Individual(9, self._gen_individual())]
 
     class _Channel(object):
         def __init__(self, connection, channel, queue_name, exchange, exchange_type, routing_key):
