@@ -240,8 +240,8 @@ class Messenger(threading.Thread):
         message to be delivered in PUBLISH_INTERVAL seconds.
 
         """
-        # logger.info('Scheduling next message for %0.1f seconds',
-        #            self.PUBLISH_INTERVAL)
+        logger.info('Scheduling next message for %0.1f seconds',
+                    self.PUBLISH_INTERVAL)
         self._connection.add_timeout(self.PUBLISH_INTERVAL,
                                      self.publish_message)
 
@@ -315,8 +315,8 @@ class Messenger(threading.Thread):
         :param str|unicode body: The message body
 
         """
-        logger.info('Received message # %s from %s: %s',
-                    basic_deliver.delivery_tag, properties.app_id, body)
+        #logger.info('Received message # %s from %s: %s',
+        #            basic_deliver.delivery_tag, properties.app_id, body)
 
         received = jsonpickle.decode(body)
         if received is not None:
